// page layout init

function initLayout() {}
function initInteractivity() {
  var screenApi = new ScreenApi();

  screenApi.activateInteractivity({
    selector: "#open-book-button",
    onShow: function () {
      var info = screenApi.initializeTime();
      $("#timepicker").show();
      $("#duration").val(15);
      var infoHolder = collectTimeInfo(info);
      $("#time-info").html(infoHolder);
    },
    onHide: function () {
      $("#timepicker").hide();
    },
  });

  screenApi.activateInteractivity({
    selector: "#single-open-book-button",
    onShow: function () {
      var info = screenApi.initializeTime();
      $("#single-timepicker").show();
      $("#single-duration").val(15);
      var infoHolder = collectTimeInfo(info);
      $("#single-time-info").html(infoHolder);
    },
    onHide: function () {
      screenApi.book();
    },
  });

  $("#book-button").click(function () {
    screenApi.book();
    //with callback example
    /*screenApi.book(duration, function (result) {
      console.log("result");
      console.log(result);
    });*/
  });
  $("#duration").keypress(function (e) {
    if (e.which == 13) {
      var duration = parseInt($("#duration").val(), 10);
      var info = screenApi.updateTime(duration);
      var infoHolder = collectTimeInfo(info);
      $("#time-info").html(infoHolder);
      $("#duration").focus().select();
    }
  });

  screenApi.activateInteractivity({
    selector: "#open-reschedule-button",
    onShow: function () {
      // console.log("reschedule onShow");
      var info = screenApi.initializeTime();
      $("#timepicker-reschedule").toggle();
      $("#duration-reschedule").val(15);
      var infoHolder = collectTimeInfo(info);
      $("#time-info-reschedule").html(infoHolder);
      $("#duration-reschedule").focus().select();
    },
    onHide: function () {
      // console.log("reschedule onShow");
      $("#timepicker-reschedule").hide();
    },
  });

  $(".defect").click(function () {
    console.log("defect activated");
    var id = this.id.split("-")[1];
    var screenData = new ScreenData();
    var defectJson = screenData.getDefect(id);

    if (defectJson.IsTriggered) {
      screenApi.clearDefect(id);
      return;
    }
    if (!defectJson.AllowCommentAtScreen) {
      screenApi.reportDefect(id);
      return;
    }

    var options = {
      template: "#errorReportTemplate",
      data: defectJson,
      actions: [
        {
          selector: "#defect-submit",
          action: function () {
            // alert("submitting with comment:" + $("#defect-comment").val());
            screenApi.reportDefect(id, $("#defect-comment").val(), function () {
              $.colorbox.close();
            });
          },
        },
      ],
    };
    var screenDialog = new ScreenApiDialog();
    ScreenModule.dialog.open(options);
  });

  $("#reschedule-button").click(function () {
    screenApi.reschedule();
  });
  $("#duration-reschedule").keypress(function (e) {
    if (e.which == 13) {
      var duration = parseInt($("#duration-reschedule").val(), 10);
      var info = screenApi.updateTime(duration);
      var infoHolder = collectTimeInfo(info);
      $("#time-info-reschedule").html(infoHolder);
      $("#duration-reschedule").focus().select();
    }
  });

  screenApi.activateInteractivity({
    selector: "#end-button",
    action: function () {
      screenApi.endNow();
    },
    confirm: true,
  });

  screenApi.activateInteractivity({
    selector: "#confirm-next-button",
    action: function () {
      screenApi.confirmNext();
    },
    confirm: false,
  });

  screenApi.activateInteractivity({
    selector: "#confirm-current-button",
    action: function () {
      screenApi.confirmCurrent();
    },
    confirm: false,
  });
}

function collectTimeInfo(info) {
  var html = [
    '<span class="explain">',
    "Duration:" + info.duration,
    "<br/>",
    "MaxDuration:" + info.maxDuration,
    "<br/>",
    "MinDuration:" + info.minDuration,
    "<br/>",
    "Date:" + info.date,
    "<br/>",
    "FormatedTime:" + info.formatedTime,
    "<br/>",
    "EndsInText:" + info.endsInText,
    "<br/>",
    "Message:" + info.message,
    "<br/>",
    "Can add 15:" + info.canAdd15,
    "<br/>",
    "Can add 30:" + info.canAdd30,
    "<br/>",
    "Can add 45:" + info.canAdd45,
    "<br/>",
    "Can add 60:" + info.canAdd60,
    "<br/>",
    "Can rem 15:" + info.canRem15,
    "<br/>",
    "Can rem 30:" + info.canRem30,
    "<br/>",
    "Can rem 45:" + info.canRem45,
    "<br/>",
    "Can rem 60:" + info.canRem60,
    "<br/>",
    "</div>",
  ].join("");
  return html;
}
