﻿(function ($) {
    $.fn.numeric = function (options) {

        var defaults = {
            min: "",
            max: "",
            allow: "",
            alertColor: "",
            defaultValue: "",
            setDefaultValueOn: "", //keyup,change
            allowEmpty: true,
            disableControls: ""
        };
        var options = $.extend(defaults, options);
      
        var isValid = true;
        if ($(this).val() === '' && !options.allowEmpty) {
            $(this).val(options.defaultValue);
        }

        function disableOnInvalid(disable) {
            var disableControls = options.disableControls;
            if (disableControls.length == 0)
                return;

            var controls = disableControls.split(',');

            for (var i = 0; i < controls.length; i++) {
                if ($(controls[i]).length > 0) {
                    if (disable)
                        $(controls[i]).prop("disabled", "true");
                    else
                        $(controls[i]).removeAttr("disabled");
                }
            }
        }

        function RemoveAlert(element) {
            if (options.alertColor.length > 0) {
                $(element).each(function (idx, el) {
                    el.style.backgroundColor = '';
                });
            }

        }

        function SetAlert(element) {
            if (options.alertColor.length > 0) {
                $(element).each(function (idx, el) {
                    el.style.backgroundColor = options.alertColor;
                });
            }

        }

        function Validate(element, setDefaultValue) {
            var opt = getElementOptions($(element));
            if ($(element).val() == '' && opt.defaultValue.length > 0) {
                if (setDefaultValue) {
                    $(element).val(opt.defaultValue);
                    if (opt.setDefaultValueOn.indexOf('keyup') > -1) {
                        $(element).select();
                        $(element).trigger('keyup');
                    }
                    else if (opt.setDefaultValueOn.indexOf('change') > -1)
                        $(element).trigger('change');
                    RemoveAlert(element);
                    return true;
                }
                else {
                    disableOnInvalid(true);
                    SetAlert(element);
                    return false;
                }
            }
            else if ($(element).val() == '' && !opt.allowEmpty) {
                disableOnInvalid(true);
                SetAlert(element);
                return false;
            }
            else if (opt.max.length > 0 && parseInt(opt.max, 10) < parseInt($(element).val(), 10)) {
                $(element).val(opt.max);
                $(element).select();
                return false;
            }
            else if (opt.min.length > 0 && parseInt(opt.min, 10) > parseInt($(element).val(), 10)) {
                $(element).val(opt.min);
                $(element).select();
                return false;
            }
            else {
                disableOnInvalid(false);
                RemoveAlert(element);
                return true;
            }
        }

        function getAllow(el) {
            var allow = getElementOptions(el).allow;
            var attrName = 'data-numeric-options';
            var attr = el.attr(attrName);
            if (attr) {
                var attrJson = $.parseJSON(attr);
                if (attrJson && attrJson.allow) {
                    allow = attrJson.allow;
                }
            }
            return allow;
        }

        function getElementOptions(el) {
                var attrName = 'data-numeric-options';
                var attr = el.attr(attrName);

                if (typeof attr !== 'undefined' && attr !== false) {
                    var attrJson = $.parseJSON(attr);
                    return $.extend(options, attrJson);
                }
            return options;
        }

        return this.each(function () {
            $(this).addClass('isNumeric');
       

            $(this).keypress(function (e) {
                //TODO:hack somhow allow is globally on all elements, fix later
                var allow = getAllow($(this));
                if (e.which === 13) //always allow enter
                    return true;
                if (!(/*(e.which >= 48 && e.which <= 57) || this is only numbers*/ e.which == 8/*backspace*/ /*|| e.which == 46delete, but also .*/)) {
                    var reg = new RegExp('[' + 0 + '-' + 9 + allow + ']', 'g');
                    if (!String.fromCharCode(e.which).match(reg)) {
                        return false;
                    }
                }
            });

            $(this).keyup(function (e) {
                var setDefaults = options.setDefaultValueOn.indexOf('keyup') > -1;
                if (setDefaults) {
                    var validation = Validate('#' + this.id, setDefaults);
                    if (!validation) {
                        $('#' + this.id).select();
                        e.returnValue = false;
                    }
                    return validation;
                }
            });

            $(this).change(function (e) {
                var setDefaults = options.setDefaultValueOn.indexOf('change') > -1;
                if (setDefaults) {
                    var validation = Validate('#' + this.id, setDefaults);
                    if (!validation) {
                        $('#' + this.id).select();
                        e.returnValue = false;
                    }
                    return validation;
                }
            });

            $(this).click(function () {
                this.select();

            });
        });

    };
})(jQuery);  