﻿function ScreenErrorHandler(options) {
  var settings = $.extend(
    {
      logurl: null,
      imagePath: null,
      localization: null,
      onError: function () {},
    },
    options
  );

  var imagePath = settings.imagePath;
  var localization = settings.localization;
  var logurl = settings.logurl;
  var screenHelper = new ScreenHelper();
  var showRedOnError = true;
  var showErrorWhenCountIs = 3;
  var showErrorAfterCount = 0;

  this.setup = function () {
    setupImpl();
  };

  this.logFormatedError = function (status, statusText, responseText) {
    addToErrorLog("AJAX", status, statusText, responseText);
  };

  this.releaseErrorMode = function () {
    logThis("releaseErrorMode");
    showErrorAfterCount = 0;
    var ulId = "ErrorPanel_ul";
    var ulElement = $("#" + ulId);
    ulElement.remove();
    $("#ErrorAlert").hide();
  };

  function doReload() {
    var getUrl = window.location.href;
    getUrl = getUrl.replace("ShowContent", "GetDisplayData");

    $.get(getUrl, function () {
      window.parent.location.reload();
    })
      .done(function () {})
      .fail(function (xhr, ajaxOptions, thrownError) {
        var status = xhr.status;
        if (confirm("Are you sure you want to reload, the server respond was: " + status + ", " + thrownError)) {
          window.parent.location.reload();
        }
      });
  }

  function setupImpl() {
    logThis("Error handler setup");
    var container = $("body");
    var errorAlert = $('<div id="ErrorAlert" style="position:absolute;bottom:0;left:0;z-index:9999999999999"></div>');

    var errorPanelLink = $('<a id="ErrorPanelLink" href="#ErrorPanel"></a>');

    var errorImage = $('<img style="border:0;" src="' + imagePath + '" />');
    errorPanelLink.append(errorImage);
    errorAlert.append(errorPanelLink);
    container.append(errorAlert);

    var errorWrapper = $('<div id="ErrorWrapper"></div>');
    var errorPanel = $('<div id="ErrorPanel"></div>');
    errorWrapper.append(errorPanel);
    errorPanel.append($("<br />"));
    var headerText = $('<label style="font-size:20px">' + localization.ErrorOccurredTryingToResolve + "</label>");
    var errorPanelReload = $('<a class="ErrorPanelReload" href="#">Reload</a>');
    errorPanelReload.click(function () {
      doReload();
    });
    errorPanel.append(headerText);
    errorPanel.append("&nbsp;&nbsp;&nbsp;");
    errorPanel.append(errorPanelReload);
    errorPanel.append($("<br /><br />"));
    var errorPanelDetail = $('<a class="ErrorPanelDetail" href="#">' + localization.TechnicalDetails + "</a>");
    errorPanelDetail.click(function () {
      $("#ErrorPanelList").toggle();
    });
    errorPanel.append(errorPanelDetail);
    errorPanel.append($("<br /><br />"));
    var errorPanelList = $('<div id="ErrorPanelList"></div>');
    errorPanel.append(errorPanelList);
    container.append(errorWrapper);
    errorAlert.hide();
    errorPanelList.hide();
    errorWrapper.hide();

    errorPanelLink.fancybox({
      transitionIn: "elastic",
      transitionOut: "elastic",
      speedIn: 200,
      speedOut: 200,
      overlayShow: true,
      hideOnOverlayClick: true,
      autoScale: true,
      type: "inline",
    });

    window.onerror = customHandler;
  }

  function customHandler(desc, page, line, chr, more) {
    var msg = "undefined";
    try {
      if (typeof desc === "string") {
        msg = getLogText(desc, page, line, chr, more);
        settings.onError(msg);
        logError(getClientLogText(desc, page, line, chr, more));
      } else if (desc instanceof Event) {
        var evtInfo = copyEventProps(desc, ["target", "currentTarget"]);
        msg = JSON.stringify(evtInfo);
      }
    } catch (err) {
      msg = err.message;
    }

    logErrorToServer(msg);

    return true;
  }

  function getClientLogText(desc, page, line, chr, more) {
    return "\nPage address:      \t" + page + "\nLine number:       \t" + line + "\nError description: \t" + desc;
  }
  function getLogText(desc, page, line, chr, more) {
    var extratext = "]M:[" + more + "]";
    if (desc == extratext) {
      extratext = "";
    }
    return "P:[" + "page-omitted" + "]L:[" + line + "]D:[" + desc + "]" + "]C:[" + chr + "]" + extratext;
  }

  function logErrorToServer(msg) {
    if (logurl) {
      screenHelper.logErrorImpl(logurl, msg);
    }
  }

  function copyEventProps(evt, tryProps) {
    var props = getDefinedProps(evt, tryProps);
    for (var property in event) {
      if (event.hasOwnProperty(property)) {
        props[property] = event[property];
      }
    }
    return props;
  }

  function getDefinedProps(evt, tryProps) {
    var props = {};
    for (var i = 0; i < tryProps.length; i++) {
      var value = "Undefined";
      if (evt[tryProps[i]] != null) {
        value = evt[tryProps[i]];
      }
      var domElement = $(value);
      if (domElement.length == 1) {
        props[tryProps[i]] = tryGetDomProps(domElement);
      } else {
        props[tryProps[i]] = value;
      }
    }
    return props;
  }

  function tryGetDomProps(el) {
    var props = {};
    el.each(function () {
      $.each(this.attributes, function () {
        if (this.specified) {
          props[this.name] = this.value;
        }
      });
    });
    return props;
  }

  function addToErrorLog(type, status, statusText, responseText) {
    var detailId = getRandomId();
    var ulElement = getErrorElement();
    var visibleText = localization.NoDetails;
    if (responseText != null && responseText.length > 0) {
      visibleText =
        "<span class='ErrorPanelLineDetail' onmouseover='$(this).css(\"cursor\",\"pointer\");'  onmouseout='$(this).css(\"cursor\",\"auto\");' onclick='$(this).parent().next().next().toggle()'>" +
        localization.Details +
        "</span>";
    }

    var newLi = $("<li>" + type + " - " + status + "(" + statusText + ")" + " - " + visibleText + "</li>");
    ulElement.append(newLi);
    ulElement.append($("<li>&nbsp;</li>"));
    ulElement.append(
      $('<li class="ErrorDetail" id="err' + detailId + '" style="display:none;">' + htmlEncode(responseText) + "</li>")
    );
  }

  function htmlEncode(value) {
    //create a in-memory div, set it's inner text(which jQuery automatically encodes)
    //then grab the encoded contents back out.  The div never exists on the page.
    return $("<div/>").text(value).html();
  }

  function logError(message) {
    addToErrorLog("JS", "", "", message);
  }

  function getRandomId() {
    return Math.floor(Math.random() * 11);
  }

  function getErrorElement() {
    showErrorAfterCount = showErrorAfterCount + 1;
    logThis(
      "releaseErrorMode=showErrorAfterCount:" + showErrorAfterCount + ",showErrorWhenCountIs:" + showErrorWhenCountIs
    );
    var ulId = "ErrorPanel_ul";
    var ulElement = $("#" + ulId);
    if (ulElement.length == 0) {
      ulElement = $('<ol id="' + ulId + '"></ol>');
      $("#ErrorPanelList").append(ulElement);
    }
    if (showRedOnError && showErrorAfterCount >= showErrorWhenCountIs) {
      $("#ErrorAlert").css("display", "block");
    }
    return ulElement;
  }

  function logThis(txt) {
    screenHelper.logThis(txt, this);
  }

  return this;
}
