﻿function ScreenApiPincode() {
  var lastPincodeSuccessful = false;
  var usingHandlebars = false;
  this.addPincodeWatch = function (callback, noPincode, confirm, handlebars) {
    console.log("addPincodeWatch");
    lastPincodeSuccessful = false;
    usingHandlebars = handlebars;
    if (!noPincode && ScreenModule.data.isPincodeRequired()) {
      alertPincode(function (success) {
        ScreenModule.dialog.done();
        if (callback) {
          return callback(success);
        }
      }, handlebars);
    } else if (confirm) {
      this.addConfirmWatch(function (isConfirm) {
        if (callback) {
          return callback(isConfirm);
        }
      }, confirm);
    } else {
      return callback(true);
    }
  };

  this.addConfirmWatch = function (callback, confirm) {
    if (confirm) {
      alertConfirm(function (isConfirm) {
        if (callback) {
          return callback(isConfirm);
        }
      });
    } else {
      return callback(true);
    }
  };

  function getPinCode() {
    return ScreenModule.data.getPincode();
  }

  function alertConfirm(callback) {
    swal(
      {
        title: "",
        text: "Are you sure",
        type: "info",
        confirmButtonText: "OK",
        showCancelButton: true,
      },
      function (isConfirm) {
        callback(isConfirm);
      }
    );
  }

  function alertPincode(callback, handlebars) {
    var settings = ScreenModule.settings.settings();
    var callbackDone = false;
    var options = {
      template: "#pincodeTemplate",
      data: settings.localization,
      onLoaded: onPincodeLoaded(function (success) {
        if (!callbackDone) {
          callbackDone = true;
          callback(success);
        }
      }),
      onClosed: function () {
        if (!callbackDone) {
          callbackDone = true;
          callback(lastPincodeSuccessful);
        }
      },
      handlebars: handlebars,
    };
    ScreenModule.dialog.open(options);
  }

  var lastKeyInput = new Date().getTime();
  var lastKeyValue = "";
  var pincodeInterval;
  function loadKeyboardWhenReady(callback) {
    if ($("#pincodeValue").length > 0) {
      clearInterval(pincodeInterval);
      if (usingHandlebars) {
        loadHandlebarsKeyboard(callback);
      } else {
        loadTemplateKeyboard(callback);
      }
    }
  }

  function loadTemplateKeyboard(callback) {
    var settings = ScreenModule.settings.settings();
    $("#pincodeValue").keyboard({
      layout: "custom",
      customLayout: {
        default: ["1 2 3", "4 5 6", "7 8 9", "{clear} 0 {cancel}"],
      },
      display: {
        clear: "Clear:clear the Content",
      },
      maxLength: 4,
      lockInput: true,
      initialFocus: true,
      restrictInput: true, // Prevent keys not in the displayed keyboard from being typed in
      useCombos: false, // don't want A+E to become a ligature
      alwaysOpen: true,
      appendLocally: true,
      validate: function () {
        return true;
      },
      accepted: function () {
        lastPincodeSuccessful = true;
        callback(true);
      },
      canceled: function () {
        callback(false);
      },
      change: function (base, el, e) {
        var value = el.$preview.val();
        var curr = new Date().getTime();
        var time = curr - lastKeyInput;
        var currVal = "";
        if (value.length > 0) {
          currVal = value[0];
        }
        if (time < 400 && currVal == lastKeyValue && !isiPad()) {
          el.$preview.val(value.substring(1, value.length));
          return;
        }

        lastKeyInput = curr;
        lastKeyValue = currVal;
        $("#pincodeError").html("");
        var ss = "";
        for (var i = 0; i < value.length; i++) {
          ss += "<img src='../../Content/Images/star.png' style='width:35px;margin-left:36px;' />";
        }

        $("#maskInput").html(ss);
        if (value.length > 0) {
          $(".ui-keyboard-cancel").css("color", "#BCBCBC");
          $(".ui-keyboard-clear").css("color", "#FFFFFF");
        }
        if (value.length < 4) {
          return;
        }
        value = value.split("").reverse().join("");
        value = hex_sha256(value).toUpperCase();
        if (value === getPinCode()) {
          setTimeout(function () {
            $("#pincodeValue").keyboard().getkeyboard().accept();
          }, 100);
        } else {
          el.$preview.val("");
          $("#pincodeError").html(settings.localization.WrongPinCode);
          setTimeout(function () {
            $("#maskInput").html("");
            $(".ui-keyboard-cancel").css("color", "#FFFFFF");
            $(".ui-keyboard-clear").css("color", "#BCBCBC");
          }, 100);
        }
      },
    });
    $.keyboard.keyaction.clear = function (base) {
      base.$preview.val("");
      $(".ui-keyboard-clear").css("color", "#BCBCBC");
    };

    var dd = $(".ui-keyboard-preview");
    dd.height(5);
    dd.css("display", "none");
    var maskInputContainer = $("<div id='maskInputContainer' />");
    var firstdiv = $("<div id='maskInput' />");
    maskInputContainer.css({
      padding: "5px 12px 5px 13px",
      "background-color": "#272727",
    });
    firstdiv.css({
      height: "45px",
      width: "390px",
      "padding-top": "16px",
      "font-size": "75px",
      "background-color": "#444444",
      color: "#A09D9D",
      "text-align": "left",
    });
    maskInputContainer.append(firstdiv);
    dd.after(maskInputContainer);

    $(".ui-keyboard-button,#maskInput").css({
      background: "#4a4a4a",
      "background-image": "-webkit-linear-gradient(top, #676767, #4a4a4a)",
      "background-image": "-moz-linear-gradient(top, #676767, #4a4a4a)",
      "background-image": "-ms-linear-gradient(top, #676767, #4a4a4a)",
      "background-image": "-o-linear-gradient(top, #676767, #4a4a4a)",
      "background-image": "linear-gradient(to bottom, #676767, #4a4a4a)",
    });
    $(".ui-keyboard-button").css({
      "border-radius": "3px",
      width: "105px",
    });

    $("#maskInput").css({
      height: "50px",
      width: "326px",
    });
    $(".ui-keyboard-button[data-value='2']").append("<div class='keyboard-chars'>ABC</div>");
    $(".ui-keyboard-button[data-value='3']").append("<div class='keyboard-chars'>DEF</div>");
    $(".ui-keyboard-button[data-value='4']").append("<div class='keyboard-chars'>GHI</div>");
    $(".ui-keyboard-button[data-value='5']").append("<div class='keyboard-chars'>JKL</div>");
    $(".ui-keyboard-button[data-value='6']").append("<div class='keyboard-chars'>MNO</div>");
    $(".ui-keyboard-button[data-value='7']").append("<div class='keyboard-chars'>QPRS</div>");
    $(".ui-keyboard-button[data-value='8']").append("<div class='keyboard-chars'>TUV</div>");
    $(".ui-keyboard-button[data-value='9']").append("<div class='keyboard-chars'>WXYZ</div>");
    $(".ui-keyboard-button[data-value='0']").css({ "text-align": "center" });
    $(".keyboard-chars").css({
      display: "inline",
      "font-size": "12px",
      width: "200px",
      "padding-left": "5px",
      color: "#BCBCBC",
    });
    $(".ui-keyboard-cancel,.ui-keyboard-clear").css({
      "font-size": "16px",
      color: "#BCBCBC",
    });
    $("#pincodeValue_keyboard").css({ width: "350px", background: "rgb(39, 39, 39)", top: "-30px" });
  }

  function loadHandlebarsKeyboard(callback) {
    var settings = ScreenModule.settings.settings();
    $("#pincodeValue").keyboard({
      width: 300,
      layout: "custom",
      customLayout: {
        default: ["1 2 3", "4 5 6", "7 8 9", "{clear} 0 {cancel}"],
      },
      display: {
        clear: "Clear:clear the Content",
      },
      maxLength: 4,
      lockInput: true,
      initialFocus: true,
      restrictInput: true, // Prevent keys not in the displayed keyboard from being typed in
      useCombos: false, // don't want A+E to become a ligature
      alwaysOpen: true,
      appendLocally: true,
      validate: function () {
        return true;
      },
      accepted: function () {
        console.log("accepted");
        lastPincodeSuccessful = true;
        callback(true);
      },
      canceled: function () {
        callback(false);
      },
      change: function (base, el, e) {
        var value = el.$preview.val();
        var curr = new Date().getTime();
        var time = curr - lastKeyInput;
        var currVal = "";
        if (value.length > 0) {
          currVal = value[0];
        }
        if (time < 100 && currVal == lastKeyValue && !isiPad()) {
          el.$preview.val(value.substring(1, value.length));
          return;
        }

        lastKeyInput = curr;
        lastKeyValue = currVal;
        $("#pincodeError").html("");
        var ss = "";
        for (var i = 0; i < value.length; i++) {
          ss += "&nbsp;&bull;&nbsp;";
        }

        $("#maskInput").html(ss);
        if (value.length > 0) {
          $(".ui-keyboard-cancel").css("color", "#BCBCBC");
          $(".ui-keyboard-clear").css("color", "#FFFFFF");
        }
        if (value.length < 4) {
          return;
        }
        value = value.split("").reverse().join("");
        value = hex_sha256(value).toUpperCase();
        if (value === getPinCode()) {
          setTimeout(function () {
            $("#pincodeValue").keyboard().getkeyboard().accept();
          }, 100);
        } else {
          el.$preview.val("");
          $("#pincodeError").html(settings.localization.WrongPinCode);
          setTimeout(function () {
            $("#maskInput").html("");
            $(".ui-keyboard-cancel").css("color", "#FFFFFF");
            $(".ui-keyboard-clear").css("color", "#BCBCBC");
          }, 100);
        }
      },
    });
    $.keyboard.keyaction.clear = function (base) {
      base.$preview.val("");
      $(".ui-keyboard-clear").css("color", "#BCBCBC");
    };

    var dd = $(".ui-keyboard-preview");
    dd.height(5);
    dd.css("display", "none");
    if ($("#maskInput").length == 0) {
      var firstdiv = $("<div id='maskInput' />");
      dd.after(firstdiv);
    }
  }

  function onPincodeLoaded(callback) {
    pincodeInterval = setInterval(function () {
      loadKeyboardWhenReady(callback);
    }, 1);
  }

  function isiPad() {
    return navigator.userAgent.match(/iPad/i) != null;
  }

  function getCssLatency() {
    var data = ScreenModule.data.getCurrent();

    if (data.length) {
      //areascreen
      return 600;
    }
    return 1;
  }
}

$.fn.bindFirst = function (name, fn) {
  // bind as you normally would
  // don't want to miss out on any jQuery magic
  this.on(name, fn);

  // Thanks to a comment by @Martin, adding support for
  // namespaced events too.
  this.each(function () {
    var handlers = $._data(this, "events")[name.split(".")[0]];
    // take out the handler we just inserted from the end
    var handler = handlers.pop();
    // move it at the beginning
    handlers.splice(0, 0, handler);
  });
};
